@@ -1,10 +1,10 @@
 import os
 import re
-from typing import Any, Dict, List
 
 from commitizen import defaults
 from commitizen.cz.base import BaseCommitizen
 from commitizen.cz.utils import multiple_line_breaker, required_validator
+from commitizen.defaults import Questions
 
 __all__ = ["ConventionalCommitsCz"]
 
@@ -31,7 +31,7 @@ class ConventionalCommitsCz(BaseCommitizen):
     bump_pattern = defaults.bump_pattern
     bump_map = defaults.bump_map
     commit_parser = defaults.commit_parser
-    changelog_pattern = defaults.bump_pattern
+    version_parser = defaults.version_parser
     change_type_map = {
         "feat": "Feat",
         "fix": "Fix",
@@ -39,8 +39,8 @@ class ConventionalCommitsCz(BaseCommitizen):
         "perf": "Perf",
     }
 
-    def questions(self) -> List[Dict[str, Any]]:
-        questions: List[Dict[str, Any]] = [
+    def questions(self) -> Questions:
+        questions: Questions = [
             {
                 "type": "list",
                 "name": "prefix",
